"""Deep Learning library for Model Building, Interpretability, Visualization,
API Building & Deployment."""

__version__ = "0.1.0b4"
__license__ = "Apache License 2.0"

from chitra.image import Chitra
